Version 0.8.1 — Version 0.9.0.dev0

# Version 0.8.1

September 29, 2020

## Changelog

### Maintenance

- Make `imbalanced-learn` compatible with `scikit-learn` 1.0. #864 by Guillaume Lemaitre.

# Version 0.8.0

February 18, 2021

## Changelog

### New features

- Add the the function `imblearn.metrics.macro_averaged_mean_absolute_error` returning the average across class of the MAE. This metric is used in ordinal classification. #780 by Aurélien Massiot.

- Add the class `imblearn.metrics.pairwise.ValueDifferenceMetric` to compute pairwise distances between samples containing only categorical values. #796 by Guillaume Lemaitre.

- Add the class `imblearn.over_sampling.SMOTEN` to over-sample data only containing categorical features. #802 by Guillaume Lemaitre.

- Add the possibility to pass any type of samplers in `imblearn.ensemble.BalancedBaggingClassifier` unlocking the implementation of methods based on resampled bagging. #808 by Guillaume Lemaitre.

### Enhancements

- Add option `output_dict` in `imblearn.metrics.classification_report_imbalanced` to return a dictionary instead of a string. #770 by Guillaume Lemaitre.

- Added an option to generate smoothed bootstrap in `imblearn.over_sampling.RandomOverSampler`. It is controls by the parameter `shrinkage`. This method is also known as Random Over-Sampling Examples (ROSE). #754 by Andrea Lorenzon and Guillaume Lemaitre.

### Bug fixes

- Fix a bug in `imblearn.under_sampling.ClusterCentroids` where `voting="hard"` could have lead to select a sample from any class instead of the targeted class. #769 by Guillaume Lemaitre.

- Fix a bug in `imblearn.FunctionSampler` where validation was performed even with `validate=False` when calling `fit`. #790 by Guillaume Lemaitre.

### Maintenance

- Remove requirements files in favour of adding the packages in the `extras_require` within the `setup.py` file. #816 by Guillaume Lemaitre.

- Change the website template to use `pydata-sphinx-theme`. #801 by Guillaume Lemaitre.

### Deprecation

- The context manager `imblearn.utils.testing.warns` is deprecated in 0.8 and will be removed 1.0. #815 by Guillaume Lemaitre.